package com.magnatune.eyecreate.companionformagnatune.adapters;

import android.content.Context;
import android.graphics.drawable.BitmapDrawable;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.FragmentManager;
import android.support.v7.graphics.Palette;
import android.support.v7.widget.CardView;
import android.transition.AutoTransition;
import android.transition.Slide;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;

import com.magnatune.eyecreate.companionformagnatune.R;
import com.magnatune.eyecreate.companionformagnatune.fragments.AlbumFragment;
import com.magnatune.eyecreate.companionformagnatune.model.Album;
import com.magnatune.eyecreate.companionformagnatune.viewholders.AlbumViewHolder;
import com.squareup.picasso.Callback;
import com.squareup.picasso.Picasso;

import io.realm.RealmBasedRecyclerViewAdapter;
import io.realm.RealmResults;

public class AlbumsAdapter extends RealmBasedRecyclerViewAdapter<Album,AlbumViewHolder> {

    FragmentManager fragmentManager;

    public AlbumsAdapter(Context context, RealmResults<Album> realmResults, boolean automaticUpdate, boolean animateResults, String animateExtraColumnName,FragmentManager fragmentManager) {
        super(context, realmResults, automaticUpdate, animateResults, animateExtraColumnName);
        this.fragmentManager = fragmentManager;
    }

    public AlbumsAdapter(Context context, RealmResults<Album> realmResults, boolean automaticUpdate, boolean animateResults, String animateExtraColumnName) {
        super(context, realmResults, automaticUpdate, animateResults, animateExtraColumnName);
    }

    @Override
    public AlbumViewHolder onCreateRealmViewHolder(ViewGroup viewGroup, int i) {
        View v = inflater.inflate(R.layout.listitem_album_card,viewGroup,false);
        AlbumViewHolder albumView = new AlbumViewHolder(v);
        return albumView;
    }

    @Override
    public void onBindRealmViewHolder(final AlbumViewHolder albumViewHolder, final int i) {
        albumViewHolder.artistName.setText(realmResults.get(i).getArtist().getArtistname());
        albumViewHolder.albumName.setText(realmResults.get(i).getAlbumname());
        Picasso.with(albumViewHolder.itemView.getContext()).load(realmResults.get(i).getCover_small()).into(albumViewHolder.albumArt, new Callback() {
            @Override
            public void onSuccess() {
                Palette colors = Palette.from(((BitmapDrawable) albumViewHolder.albumArt.getDrawable()).getBitmap()).generate();
                Palette.Swatch swatch = null;
                swatch = colors.getVibrantSwatch();
                if (swatch == null) {
                    swatch = colors.getMutedSwatch();
                }
                if (swatch == null && colors.getSwatches().size() > 0) {
                    swatch = colors.getSwatches().get(0);
                }
                if (swatch != null) {
                    ((CardView) albumViewHolder.itemView).setCardBackgroundColor(swatch.getRgb());
                    albumViewHolder.albumName.setTextColor(swatch.getTitleTextColor());
                    albumViewHolder.artistName.setTextColor(swatch.getBodyTextColor());
                }
            }

            @Override
            public void onError() {

            }
        });
        albumViewHolder.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle args = new Bundle();
                args.putString(AlbumFragment.ARG_ALBUM_ID, realmResults.get(i).getAlbumsku());
                AlbumFragment fragment = new AlbumFragment();
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                    fragment.setEnterTransition(new Slide(Gravity.BOTTOM));
                    fragment.setExitTransition(new Slide(Gravity.BOTTOM));
                    fragment.setSharedElementEnterTransition(new AutoTransition());
                    fragment.setSharedElementReturnTransition(new AutoTransition());
                }
                fragment.setArguments(args);
                fragmentManager.beginTransaction()
                        .setCustomAnimations(R.anim.fragment_enter,R.anim.fragment_exit,R.anim.fragment_pop_enter,R.anim.fragment_pop_exit)
                        .addSharedElement(albumViewHolder.albumArt,"albumart")
                        .replace(R.id.fragment_holder, fragment, "tracks")
                        .addToBackStack("tracks")
                        .commit();
            }
        });
    }
}
